#
# spec file for package profile-sync-daemon
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013-2020 Artem Polishchuk & Christopher Meng
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global shortname psd
Name:           profile-sync-daemon
Version:        6.50
Release:        1.1
Summary:        Symlinks and syncs browser profile dirs to RAM thus reducing HDD/SDD calls
License:        MIT
URL:            https://github.com/graysky2/profile-sync-daemon
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  zsh
Requires:       rsync
BuildArch:      noarch

%description
Profile-sync-daemon (psd) is a tiny pseudo-daemon designed to manage your
browser's profile in tmpfs and to periodically sync it back to your physical
disc (HDD/SSD). This is accomplished via a symlinking step and an innovative
use of rsync to maintain back-up and synchronization between the two. One of
the major design goals of psd is a completely transparent user experience.

%package        zsh-completion
Summary:        zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)

%description    zsh-completion
zsh completion for %{name}.

%prep
%autosetup -p1

%build
%make_build

%install
%make_install
%fdupes %{buildroot}/%{_datadir}/%{shortname}/

%post
%{systemd_user_post %{shortname}.service}

%preun
%{systemd_user_preun %{shortname}.service}

%postun
%{systemd_user_postun_with_restart %{shortname}.service}

%files
%doc README.md
%license MIT LICENSE
%{_bindir}/%{name}
%{_bindir}/%{shortname}
%{_bindir}/%{shortname}-overlay-helper
%{_bindir}/%{shortname}-suspend-sync
%{_datadir}/%{shortname}/
%{_mandir}/man1/*.1%{?ext_man}
%{_userunitdir}/*.{service,timer}

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{shortname}

%changelog
* Sun Apr 28 2024 Dirk Müller <dmueller@suse.com>
- update to 6.50:
  * psd.in: add missing var to fix backup limit
  * Add vscode dir
  * README and MIT: update
  * Per XDG Base Directory Specification, create XDG_RUNTIME_DIR
    in /tmp
  * Fix surf support (rm wrong '/')
* Sun Oct 16 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to verion 6.48:
  * Use CHROME_CONFIG_HOME as chrome profile location
  * No ANSI escapes when logging
  * Move $VOLATILE to dedicated dir in $XDG_RUNTIME_DIR
  * psd.in: fix grep statement and VERSION
* Thu Dec 17 2020 Dan Čermák <dcermak@suse.com>
- Initial package version of profile-sync-daemon based on Fedora's package
